@@ -6,17 +6,15 @@ our ($ROUND, $PREC);
 sub __harmfrac__ {    # takes an unsigned integer
     my ($ui) = @_;
 
-    $ui || goto &Math::AnyNum::_zero;
-    $ui < 0 && goto &Math::AnyNum::_nan;
+    $ui || goto &_zero;
+    $ui < 0 && goto &_nan;
 
     # Use binary splitting for large values of n. (by Fredrik Johansson)
     # http://fredrik-j.blogspot.ro/2009/02/how-not-to-compute-harmonic-numbers.html
     if ($ui > 7000) {
 
         my $num = Math::GMPz::Rmpz_init_set_ui(1);
-
-        my $den = Math::GMPz::Rmpz_init_set_ui($ui);
-        Math::GMPz::Rmpz_add_ui($den, $den, 1);
+        my $den = Math::GMPz::Rmpz_init_set_ui($ui + 1);
 
         my $temp = Math::GMPz::Rmpz_init();
 
